.. -*- mode: rst -*-

API Reference
=============

In this section, we describe in detail the API and implementations of the ``fastlife`` module. The transparency of this section is critical to ensure that user's understand the best effort made to enhance the performance of all implementations. Much of the documentation here is generated from the docstrings in the code as a result.

.. toctree::
   :maxdepth: 2

   grid
   sequential
   utils
   exceptions
